Index: net/quic/chromium/quic_chromium_client_session.h |
diff --git a/net/quic/chromium/quic_chromium_client_session.h b/net/quic/chromium/quic_chromium_client_session.h |
index f9aa8b81fa26389aec08c30829c17000167b70c2..61bb3a2981ac8ef9ef9161d561fd7ef259b4ae12 100644 |
--- a/net/quic/chromium/quic_chromium_client_session.h |
+++ b/net/quic/chromium/quic_chromium_client_session.h |
@@ -48,7 +48,8 @@ class SSLInfo; |
class TransportSecurityState; |
using TokenBindingSignatureMap = |
- base::MRUCache<std::string, std::vector<uint8_t>>; |
+ base::MRUCache<std::pair<TokenBindingType, std::string>, |
+ std::vector<uint8_t>>; |
namespace test { |
class QuicChromiumClientSessionPeer; |
@@ -197,9 +198,11 @@ class NET_EXPORT_PRIVATE QuicChromiumClientSession |
// Gets the SSL connection information. |
bool GetSSLInfo(SSLInfo* ssl_info) const; |
// Signs the exported keying material used for Token Binding using key |*key| |
// and puts the signature in |*out|. Returns a net error code. |
Error GetTokenBindingSignature(crypto::ECPrivateKey* key, |
+ TokenBindingType tb_type, |
std::vector<uint8_t>* out); |
// Performs a crypto handshake with the server. |
@@ -197,9 +198,11 @@ class NET_EXPORT_PRIVATE QuicChromiumClientSession |
// Gets the SSL connection information. |
bool GetSSLInfo(SSLInfo* ssl_info) const; |
- // Signs the exported keying material used for Token Binding using key |*key| |
- // and puts the signature in |*out|. Returns a net error code. |
+ // Generates the signature used in Token Binding using key |*key| and for a |
+ // Token Binding of type |tb_type|, putting the signature in |*out|. Returns a |
+ // net error code. |
Error GetTokenBindingSignature(crypto::ECPrivateKey* key, |